@@ -31,42 +31,31 @@ if AIRFLOW_V_3_0_PLUS:
 else:
     # Airflow 2 path
     from airflow.decorators import task  # type: ignore[attr-defined,no-redef]
-from airflow.models.baseoperator import chain
 from airflow.models.dag import DAG
 from airflow.providers.google.cloud.operators.gcs import GCSCreateBucketOperator, GCSDeleteBucketOperator
 from airflow.providers.google.cloud.transfers.http_to_gcs import HttpToGCSOperator
-from airflow.providers.standard.operators.bash import BashOperator
-from airflow.utils.trigger_rule import TriggerRule
 
-from system.google import DEFAULT_GCP_SYSTEM_TEST_PROJECT_ID
+try:
+    from airflow.sdk import TriggerRule
+except ImportError:
+    # Compatibility for Airflow < 3.1
+    from airflow.utils.trigger_rule import TriggerRule  # type: ignore[no-redef,attr-defined]
+
 from tests_common.test_utils.api_client_helpers import create_airflow_connection, delete_airflow_connection
 
 ENV_ID = os.environ.get("SYSTEM_TESTS_ENV_ID", "default")
-PROJECT_ID = os.environ.get("SYSTEM_TESTS_GCP_PROJECT") or DEFAULT_GCP_SYSTEM_TEST_PROJECT_ID
+PROJECT_ID = os.environ.get("SYSTEM_TESTS_GCP_PROJECT", "default")
 
 DAG_ID = "example_http_to_gcs"
 BUCKET_NAME = f"bucket-{DAG_ID}-{ENV_ID}"
 
-cmd = """
-#!/bin/bash
-
-echo 'foo' > /tmp/test_file
-
-cd /tmp
-
-nohup python3 -m http.server 8083 > /dev/null 2>&1 &
-
-echo $!
-sleep 2
-exit 0
-"""
 
 with DAG(
     DAG_ID,
     schedule="@once",
     start_date=datetime(2025, 1, 1),
     catchup=False,
-    tags=["example"],
+    tags=["example, http_to_gcs"],
 ) as dag:
     conn_id_name = f"{ENV_ID}-http-conn-id"
 
@@ -74,7 +63,7 @@ with DAG(
 
     @task(task_id="create_connection")
     def create_connection(conn_id_name: str):
-        connection: dict[str, Any] = {"conn_type": "http", "host": "localhost", "port": 8083}
+        connection: dict[str, Any] = {"conn_type": "http", "host": "http://airflow.apache.org"}
         create_airflow_connection(
             connection_id=conn_id_name,
             connection_conf=connection,
@@ -82,24 +71,16 @@ with DAG(
 
     set_up_connection = create_connection(conn_id_name)
 
-    start_server = BashOperator(bash_command=cmd, task_id="start_server")
-
     # [START howto_transfer_http_to_gcs]
     http_to_gcs_task = HttpToGCSOperator(
         task_id="http_to_gcs_task",
         http_conn_id=conn_id_name,
-        endpoint="/test_file",
+        endpoint="/community",
         bucket_name=BUCKET_NAME,
-        object_name="test_file",
+        object_name="endpoint_http_content_file",
     )
     # [END howto_transfer_http_to_gcs]
 
-    stop_server = BashOperator(
-        task_id="stop_simple_http_server",
-        bash_command='kill {{ti.xcom_pull(task_ids="start_server")}}',
-        trigger_rule=TriggerRule.ALL_DONE,
-    )
-
     delete_bucket = GCSDeleteBucketOperator(
         task_id="delete_bucket", bucket_name=BUCKET_NAME, trigger_rule=TriggerRule.ALL_DONE
     )
@@ -110,17 +91,13 @@ with DAG(
 
     delete_connection_task = delete_connection(connection_id=conn_id_name)
 
-    chain(
+    (
         # TEST SETUP
-        create_bucket,
-        set_up_connection,
-        start_server,
+        [create_bucket, set_up_connection]
         # TEST BODY
-        http_to_gcs_task,
+        >> http_to_gcs_task
         # TEST TEARDOWN
-        stop_server,
-        delete_bucket,
-        delete_connection_task,
+        >> [delete_bucket, delete_connection_task]
     )
 
     from tests_common.test_utils.watcher import watcher
